//#########################################################################
// File: LCD.H
//
// Ansteuerung einer LCD-Anzeige
//
//#########################################################################
// Last change: 04.07.2007
//#########################################################################
// Compiler: AVR-GCC 3.4.5
// Compiler: AVR-GCC 4.1.1
//#########################################################################
//@{

#ifndef __LCD_H
#define __LCD_H

// Some usefull defines
#define NOP() asm volatile ("nop" ::)
#define sbi(portn, bitn) ((portn)|=(1<<(bitn)))
#define cbi(portn, bitn) ((portn)&=~(1<<(bitn)))

#if defined (__AVR_ATmega32__) || defined (__AVR_ATmega323__) || defined (__AVR_ATmega161__) || defined (__AVR_ATmega644__)
 #define LCD_RS_PIN	5 //LCD Register Select Pin
 #define LCD_RS_PORT	PORTD
 #define LCD_RS_DDR	DDRD
 #define LCD_CS_PIN	4 //LCD Chip Select Pin
 #define LCD_CS_PORT	PORTD
 #define LCD_CS_DDR	DDRD

 #define LCD_DATA_PORT	PORTC //LCD Data Port
 #define LCD_DATA_DDR	DDRC

#elif defined (__AVR_ATmega128__) || defined (__AVR_ATmega64__)
 #define LCD_RS_PIN	2 //LCD Register Select Pin
 #define LCD_RS_PORT	PORTC
 #define LCD_RS_DDR	DDRC
 #define LCD_CS_PIN	3 //LCD Chip Select Pin
 #define LCD_CS_PORT	PORTC
 #define LCD_CS_DDR	DDRC

 #define LCD_DATA_PORT	PORTC //LCD Data Port
 #define LCD_DATA_DDR	DDRC
 #define LCD_DATA_PIN	PINC

#elif defined (__AVR_ATmega168__) || defined (__AVR_ATmega48__) || defined (__AVR_ATmega88__) || defined (__AVR_ATmega8__)
 #define LCD_RS_PIN	0 //LCD Register Select Pin
 #define LCD_RS_PORT	PORTC
 #define LCD_RS_DDR	DDRC
 #define LCD_CS_PIN	1 //LCD Chip Select Pin
 #define LCD_CS_PORT	PORTC
 #define LCD_CS_DDR	DDRC

 #define LCD_DATA_PORT	PORTC //LCD Data Port
 #define LCD_DATA_DDR	DDRC
 #define LCD_DATA_PIN	PINC

#else
#  error "processor type not defined in lcd.h"
#endif

#define LCDCS_ON() { sbi(LCD_CS_PORT,LCD_CS_PIN); }
#define LCDCS_OFF() { cbi(LCD_CS_PORT,LCD_CS_PIN); }
#define LCDRS_ON() { sbi(LCD_RS_PORT,LCD_RS_PIN); }
#define LCDRS_OFF() { cbi(LCD_RS_PORT,LCD_RS_PIN); }

extern void LCDInit(void);
extern void LCDWriteByte(unsigned char);
extern void LCDWrite(char *);

extern void _LCDWrite_P(const char *s);
#define LCDWrite_P(text)   _LCDWrite_P(PSTR(text))

extern void LCDCls(void);
extern void LCDPos(unsigned char, unsigned char);
extern void ShowHex(unsigned char by);
extern void ShowHexLong(unsigned long l);
extern void Delay1ms(unsigned int);
extern void Delay100us(unsigned char);
extern void Delay1us(unsigned char time);

#endif
//@}
